@@ -1,10 +1,12 @@
 """Models for the ``subscribe`` app."""
-from django.contrib.contenttypes import generic
+from django.contrib.contenttypes.fields import GenericForeignKey
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
+from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext_lazy as _
 
 
+@python_2_unicode_compatible
 class Subscription(models.Model):
     """
     Allows a ``User`` to subscribe to anything.
@@ -29,13 +31,13 @@ class Subscription(models.Model):
         related_name='subscribed',
     )
     object_id = models.PositiveIntegerField()
-    content_object = generic.GenericForeignKey('content_type', 'object_id')
+    content_object = GenericForeignKey('content_type', 'object_id')
 
     creation_date = models.DateTimeField(
         auto_now_add=True,
         verbose_name=_('Creation date'),
     )
 
-    def __unicode__(self):
-        return '{0} subscribed to {1}'.format(
+    def __str__(self):
+        return u'{0} subscribed to {1}'.format(
             self.user.email, self.content_object)
