@@ -5,7 +5,7 @@ you can actually reach the app's views (provided it has any views, of course).
 
 """
 from django.conf import settings
-from django.conf.urls.defaults import include, patterns, url
+from django.conf.urls import include, url
 from django.contrib import admin
 
 from django.contrib.staticfiles.urls import staticfiles_urlpatterns
@@ -16,9 +16,9 @@ admin.autodiscover()
 
 urlpatterns = static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
 urlpatterns += staticfiles_urlpatterns()
-urlpatterns += patterns(
-    '',
+urlpatterns += [
     url(r'^admin/', include(admin.site.urls)),
-    url(r'^accounts/login/$', 'django.contrib.auth.views.login', name='auth_login'),
+    url(r'^accounts/login/$', 'django.contrib.auth.views.login',
+        name='auth_login'),
     url(r'^', include('subscribe.urls')),
-)
+]
